<?php

namespace Drupal\menu_block_settings_override\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\menu_block\Plugin\Block\MultipleMenuBlock;
use Drupal\menu_block_settings_override\Traits\MenuBlockSettingsOverrideTrait;

/**
 * Provides an extended Menu block with overridable settings.
 *
 * @Block(
 *   id = "multiple_menu_block",
 *   admin_label = @Translation("Multiple Menu block"),
 *   category = @Translation("Menus"),
 *   deriver = "Drupal\menu_block\Plugin\Derivative\MultipleMenuBlock",
 *   forms = {
 *     "settings_tray" = "\Drupal\system\Form\SystemMenuOffCanvasForm",
 *   },
 *   context_definitions = {
 *     "node" = @ContextDefinition("entity:node", label = @Translation("Node"), required = FALSE)
 *   }
 * )
 */
class MultipleMenuBlockWithOverridableSettings extends MultipleMenuBlock {

  use MenuBlockSettingsOverrideTrait;

  /**
   * This function will be used by menu_block_settings_override widget when the
   * parent field is not hidden. We allow the user to set a parent menu, taking
   * in consideration the selected menus on the original menu block.
   *
   * @param $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return array
   */
  public function blockFormField($form, FormStateInterface $form_state) {
    $config = $this->configuration;
    $form = parent::blockForm($form, $form_state);

    $menus = array_filter($config['selected_menus']);
    if (!empty($menus)) {
      /** @var \Drupal\Core\Menu\MenuParentFormSelectorInterface $menu_parent_selector */
      $menu_parent_selector = \Drupal::service('menu.parent_form_selector');
      $form['advanced']['parent'] = $menu_parent_selector->parentSelectElement(current($menus), '', $menus);
      $form['advanced']['parent'] += [
        '#title' => $this->t('Fixed parent item'),
        '#description' => $this->t('Alter the options in “Menu levels” to be relative to the fixed parent item. The block will only contain children of the selected menu link.'),
      ];
      $form['advanced']['parent']['#options'] =  ['all' => ['name'=> 'Default']] + $form['advanced']['parent']['#options'];
      $form['advanced']['parent']['#default_value'] = 'all';
    }

    return $form;
  }


}
